@@ -234,6 +234,18 @@ function configure_manila {
         iniset $MANILA_CONF DEFAULT server_migration_driver_continue_update_interval $MANILA_SERVER_MIGRATION_PERIOD_TASK_INTERVAL
     fi
 
+    if ! [[ -z $MANILA_CREATE_BACKUP_CONTINUE_TASK_INTERVAL ]]; then
+        iniset $MANILA_CONF DEFAULT driver_backup_continue_update_interval $MANILA_CREATE_BACKUP_CONTINUE_TASK_INTERVAL
+    fi
+
+    if ! [[ -z $MANILA_RESTORE_BACKUP_CONTINUE_TASK_INTERVAL ]]; then
+        iniset $MANILA_CONF DEFAULT driver_restore_continue_update_interval $MANILA_RESTORE_BACKUP_CONTINUE_TASK_INTERVAL
+    fi
+
+    if ! [[ -z $MANILA_DEFERRED_DELETE_TASK_INTERVAL ]]; then
+        iniset $MANILA_CONF DEFAULT periodic_deferred_delete_interval $MANILA_DEFERRED_DELETE_TASK_INTERVAL
+    fi
+
     if ! [[ -z $MANILA_DATA_COPY_CHECK_HASH ]]; then
         iniset $MANILA_CONF DEFAULT check_hash $MANILA_DATA_COPY_CHECK_HASH
     fi
@@ -309,7 +321,7 @@ function configure_manila {
     if [[ "$MANILA_ENFORCE_SCOPE" == True ]] ; then
         iniset $MANILA_CONF oslo_policy enforce_scope true
         iniset $MANILA_CONF oslo_policy enforce_new_defaults true
-        OS_CLOUD="devstack-system-admin"
+        OS_CLOUD="devstack-admin"
     fi
 }
 
@@ -517,13 +529,6 @@ function create_manila_accounts {
 # create_default_share_group_type - create share group type that will be set as default.
 function create_default_share_group_type {
 
-    # NOTE(gouthamr): manilaclient's shell doesn't support cloud profiles;
-    # OSC is the best approach here: https://review.opendev.org/805064, but,
-    # we need a temporary workaround to use legacy credentials while we wait
-    # for OSC support
-    # TODO(gouthamr): Remove workaround when we replace the commands below
-    # with OSC equivalents
-
     local type_exists=$( openstack --os-cloud $OS_CLOUD share group type list | grep " $MANILA_DEFAULT_SHARE_GROUP_TYPE " )
     if [[ -z $type_exists ]]; then
         openstack --os-cloud $OS_CLOUD share group type create $MANILA_DEFAULT_SHARE_GROUP_TYPE $MANILA_DEFAULT_SHARE_TYPE
@@ -727,6 +732,9 @@ function install_manilaclient {
     else
         pip_install python-manilaclient
     fi
+    if [[ "$GLOBAL_VENV" == "True" ]]; then
+        sudo ln -sf /opt/stack/data/venv/bin/manila /usr/local/bin
+    fi
 }
 
 # install_manila - Collect source and prepare
@@ -745,30 +753,7 @@ function install_manila {
             if [[ $(sudo zfs list &> /dev/null && sudo zpool list &> /dev/null || echo 'absent') == 'absent' ]]; then
                 # ZFS not found, try to install it
                 if is_ubuntu; then
-                    if [[ $(lsb_release -s -d) == *"14.04"* ]]; then
-                        # Trusty
-                        sudo apt-get install -y software-properties-common
-                        sudo apt-add-repository --yes ppa:zfs-native/stable
-
-                        # Workaround for bug #1609696
-                        sudo apt-mark hold grub*
-
-                        sudo apt-get -y -q update && sudo apt-get -y -q upgrade
-
-                        # Workaround for bug #1609696
-                        sudo apt-mark unhold grub*
-
-                        sudo apt-get install -y linux-headers-generic
-                        sudo apt-get install -y build-essential
-                        sudo apt-get install -y ubuntu-zfs
-
-                    elif [[ $(echo $(lsb_release -rs) '>=' 16.04 | bc -l) == 1 ]]; then
-                        # Xenial and beyond
-                        sudo apt-get install -y zfsutils-linux
-                    else
-                        echo "Only 'Trusty', 'Xenial' and newer releases of Ubuntu are supported."
-                        exit 1
-                    fi
+                    sudo apt-get install -y zfsutils-linux
                 else
                     echo "Manila Devstack plugin supports installation "\
                         "of ZFS packages only for 'Ubuntu' distros. "\
@@ -933,26 +918,11 @@ function update_tempest {
         fi
 
         TEMPEST_CONFIG=${TEMPEST_CONFIG:-$TEMPEST_DIR/etc/tempest.conf}
-        ADMIN_TENANT_NAME=${ADMIN_TENANT_NAME:-"admin"}
-        ADMIN_DOMAIN_NAME=${ADMIN_DOMAIN_NAME:-"Default"}
-        ADMIN_PASSWORD=${ADMIN_PASSWORD:-"secretadmin"}
 
         if [ $(trueorfalse False MANILA_USE_SERVICE_INSTANCE_PASSWORD) == True ]; then
             iniset $TEMPEST_CONFIG share image_password $MANILA_SERVICE_INSTANCE_PASSWORD
         fi
         iniset $TEMPEST_CONFIG share image_with_share_tools $MANILA_SERVICE_IMAGE_NAME
-        iniset $TEMPEST_CONFIG auth admin_username ${ADMIN_USERNAME:-"admin"}
-        iniset $TEMPEST_CONFIG auth admin_password ${ADMIN_PASSWORD:-"secretadmin"}
-        iniset $TEMPEST_CONFIG auth admin_tenant_name $ADMIN_TENANT_NAME
-        iniset $TEMPEST_CONFIG auth admin_domain_name $ADMIN_DOMAIN_NAME
-        iniset $TEMPEST_CONFIG identity username ${TEMPEST_USERNAME:-"demo"}
-        iniset $TEMPEST_CONFIG identity password $ADMIN_PASSWORD
-        iniset $TEMPEST_CONFIG identity tenant_name ${TEMPEST_TENANT_NAME:-"demo"}
-        iniset $TEMPEST_CONFIG identity domain_name $ADMIN_DOMAIN_NAME
-        iniset $TEMPEST_CONFIG identity alt_username ${ALT_USERNAME:-"alt_demo"}
-        iniset $TEMPEST_CONFIG identity alt_password $ADMIN_PASSWORD
-        iniset $TEMPEST_CONFIG identity alt_tenant_name ${ALT_TENANT_NAME:-"alt_demo"}
-        iniset $TEMPEST_CONFIG identity alt_domain_name $ADMIN_DOMAIN_NAME
         iniset $TEMPEST_CONFIG enforce_scope manila "$MANILA_ENFORCE_SCOPE"
 
         # If testing a stable branch, we need to ensure we're testing with supported
