@@ -23,6 +23,7 @@ class ViewBuilder(common.ViewBuilder):
         "add_share_group_quotas",
         "add_share_replica_quotas",
         "add_per_share_gigabytes_quotas",
+        "add_share_backup_quotas",
     ]
 
     def detail_list(self, request, quota_set, project_id=None,
@@ -64,3 +65,8 @@ class ViewBuilder(common.ViewBuilder):
     @common.ViewBuilder.versioned_method("2.62")
     def add_per_share_gigabytes_quotas(self, context, view, quota_set):
         view['per_share_gigabytes'] = quota_set.get('per_share_gigabytes')
+
+    @common.ViewBuilder.versioned_method("2.80")
+    def add_share_backup_quotas(self, context, view, quota_set):
+        view['backups'] = quota_set.get('backups')
+        view['backup_gigabytes'] = quota_set.get('backup_gigabytes')
