@@ -14,6 +14,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from keystoneauth1 import exceptions as ks_exec
 from keystoneauth1 import loading as ks_loading
 from neutronclient.common import exceptions as neutron_client_exc
 from neutronclient.v2_0 import client as clientv20
@@ -24,6 +25,8 @@ from manila.common import client_auth
 from manila import context
 from manila import exception
 from manila.network.neutron import constants as neutron_constants
+from manila import utils
+
 
 NEUTRON_GROUP = 'neutron'
 
@@ -31,47 +34,53 @@ NEUTRON_GROUP = 'neutron'
 neutron_opts = [
     cfg.StrOpt(
         'url',
-        default='http://127.0.0.1:9696',
-        deprecated_group="DEFAULT",
-        deprecated_name="neutron_url",
         help='URL for connecting to neutron.'),
     cfg.IntOpt(
         'url_timeout',
+        deprecated_for_removal=True,
+        deprecated_reason='This parameter has had no effect since 2.0.0. '
+                          'The timeout parameter should be used instead.',
+        deprecated_since='Yoga',
         default=30,
-        deprecated_group="DEFAULT",
-        deprecated_name="neutron_url_timeout",
         help='Timeout value for connecting to neutron in seconds.'),
     cfg.StrOpt(
         'auth_strategy',
+        deprecated_for_removal=True,
+        deprecated_reason='This parameter has had no effect since 2.0.0. '
+                          'Use the auth_type parameter to select '
+                          'authentication type',
+        deprecated_since='Yoga',
         default='keystone',
-        deprecated_group="DEFAULT",
         help='Auth strategy for connecting to neutron in admin context.'),
     cfg.StrOpt(
         'endpoint_type',
         default='publicURL',
+        choices=['publicURL', 'internalURL', 'adminURL',
+                 'public', 'internal', 'admin'],
         help='Endpoint type to be used with neutron client calls.'),
     cfg.StrOpt(
         'region_name',
         help='Region name for connecting to neutron in admin context.'),
 ]
 
-# These fallback options can be removed in/after 9.0.0 (Train)
-deprecated_opts = {
-    'cafile': [
-        cfg.DeprecatedOpt('ca_certificates_file', group="DEFAULT"),
-        cfg.DeprecatedOpt('ca_certificates_file', group=NEUTRON_GROUP),
-    ],
-    'insecure': [
-        cfg.DeprecatedOpt('api_insecure', group="DEFAULT"),
-        cfg.DeprecatedOpt('api_insecure', group=NEUTRON_GROUP),
-    ],
-}
-
 
 CONF = cfg.CONF
 LOG = log.getLogger(__name__)
 
 
+class PortBindingAlreadyExistsClient(neutron_client_exc.Conflict):
+    pass
+
+
+# We need to monkey-patch neutronclient.common.exceptions module, to make
+# neutron client to raise error specific exceptions. E.g. exception
+# PortBindingAlreadyExistsClient is raised for Neutron API error
+# PortBindingAlreadyExists. If not defined, a general exception of type
+# Conflict will be raised.
+neutron_client_exc.PortBindingAlreadyExistsClient = \
+    PortBindingAlreadyExistsClient
+
+
 def list_opts():
     return client_auth.AuthClientLoader.list_opts(NEUTRON_GROUP)
 
@@ -86,7 +95,7 @@ class API(object):
         self.config_group_name = config_group_name or 'DEFAULT'
 
         ks_loading.register_session_conf_options(
-            CONF, NEUTRON_GROUP, deprecated_opts=deprecated_opts)
+            CONF, NEUTRON_GROUP)
         ks_loading.register_auth_conf_options(CONF, NEUTRON_GROUP)
         CONF.register_opts(neutron_opts, NEUTRON_GROUP)
 
@@ -109,6 +118,7 @@ class API(object):
             context,
             endpoint_type=CONF[NEUTRON_GROUP].endpoint_type,
             region_name=CONF[NEUTRON_GROUP].region_name,
+            endpoint_override=CONF[NEUTRON_GROUP].url,
         )
 
     @property
@@ -130,6 +140,20 @@ class API(object):
                     fixed_ip=None, device_owner=None, device_id=None,
                     mac_address=None, port_security_enabled=True,
                     security_group_ids=None, dhcp_opts=None, **kwargs):
+        return self._create_port(tenant_id, network_id, host_id=host_id,
+                                 subnet_id=subnet_id, fixed_ip=fixed_ip,
+                                 device_owner=device_owner,
+                                 device_id=device_id, mac_address=mac_address,
+                                 port_security_enabled=port_security_enabled,
+                                 security_group_ids=security_group_ids,
+                                 dhcp_opts=dhcp_opts, **kwargs)
+
+    @utils.retry(retry_param=ks_exec.ConnectFailure, retries=5)
+    def _create_port(self, tenant_id, network_id, host_id=None, subnet_id=None,
+                     fixed_ip=None, device_owner=None, device_id=None,
+                     mac_address=None, port_security_enabled=True,
+                     security_group_ids=None, dhcp_opts=None, name=None,
+                     **kwargs):
         try:
             port_req_body = {'port': {}}
             port_req_body['port']['network_id'] = network_id
@@ -160,6 +184,8 @@ class API(object):
                 port_req_body['port']['device_owner'] = device_owner
             if device_id:
                 port_req_body['port']['device_id'] = device_id
+            if name:
+                port_req_body['port']['name'] = name
             if kwargs:
                 port_req_body['port'].update(kwargs)
             port = self.client.create_port(port_req_body).get('port', {})
@@ -171,10 +197,26 @@ class API(object):
                 raise exception.PortLimitExceeded()
             raise exception.NetworkException(code=e.status_code,
                                              message=e.message)
+        except ks_exec.ConnectFailure:
+            LOG.warning('Create Port: Neutron connection failure')
+            # check if port is created in neutron else re-raise connectFailure
+            search_opts = {
+                'device_id': device_id,
+                'network_id': network_id,
+                'name': name
+            }
+            try:
+                ports = self.list_ports(**search_opts)
+                return ports[0]
+            except ks_exec.ConnectFailure as kse:
+                raise kse
 
     def delete_port(self, port_id):
         try:
             self.client.delete_port(port_id)
+        except neutron_client_exc.PortNotFoundClient:
+            LOG.warning('Neutron port not found: %s', port_id)
+            pass
         except neutron_client_exc.NeutronClientException as e:
             raise exception.NetworkException(code=e.status_code,
                                              message=e.message)
@@ -190,6 +232,7 @@ class API(object):
         """List ports for the client based on search options."""
         return self.client.list_ports(**search_opts).get('ports')
 
+    @utils.retry(retry_param=ks_exec.ConnectFailure, retries=5)
     def show_port(self, port_id):
         """Return the port for the client given the port id."""
         try:
@@ -197,11 +240,14 @@ class API(object):
         except neutron_client_exc.NeutronClientException as e:
             raise exception.NetworkException(code=e.status_code,
                                              message=e.message)
+        except ks_exec.ConnectFailure as e:
+            raise e
 
     def get_all_networks(self):
         """Get all networks for client."""
         return self.client.list_networks().get('networks')
 
+    @utils.retry(retry_param=ks_exec.ConnectFailure, retries=5)
     def get_network(self, network_uuid):
         """Get specific network for client."""
         try:
@@ -210,6 +256,8 @@ class API(object):
         except neutron_client_exc.NeutronClientException as e:
             raise exception.NetworkException(code=e.status_code,
                                              message=e.message)
+        except ks_exec.ConnectFailure as e:
+            raise e
 
     def get_subnet(self, subnet_uuid):
         """Get specific subnet for client."""
@@ -249,13 +297,15 @@ class API(object):
             raise exception.NetworkException(code=e.status_code,
                                              message=e.message)
 
-    def subnet_create(self, tenant_id, net_id, name, cidr):
+    def subnet_create(self, tenant_id, net_id, name, cidr, no_gateway=False):
         subnet_req_body = {'subnet': {}}
         subnet_req_body['subnet']['tenant_id'] = tenant_id
         subnet_req_body['subnet']['name'] = name
         subnet_req_body['subnet']['network_id'] = net_id
         subnet_req_body['subnet']['cidr'] = cidr
         subnet_req_body['subnet']['ip_version'] = 4
+        if no_gateway:
+            subnet_req_body['subnet']['gateway_ip'] = None
         try:
             return self.client.create_subnet(
                 subnet_req_body).get('subnet', {})
@@ -304,6 +354,32 @@ class API(object):
             raise exception.NetworkException(code=e.status_code,
                                              message=e.message)
 
+    def bind_port_to_host(self, port_id, host, vnic_type):
+        """Add an inactive binding to existing port."""
+
+        try:
+            data = {"binding": {"host": host, "vnic_type": vnic_type}}
+            return self.client.create_port_binding(port_id, data)['binding']
+        except neutron_client_exc.PortBindingAlreadyExistsClient as e:
+            LOG.warning('Port binding already exists: %s', e)
+        except neutron_client_exc.NeutronClientException as e:
+            raise exception.NetworkException(
+                code=e.status_code, message=e.message)
+
+    def delete_port_binding(self, port_id, host):
+        try:
+            return self.client.delete_port_binding(port_id, host)
+        except neutron_client_exc.NeutronClientException as e:
+            raise exception.NetworkException(
+                code=e.status_code, message=e.message)
+
+    def activate_port_binding(self, port_id, host):
+        try:
+            return self.client.activate_port_binding(port_id, host)
+        except neutron_client_exc.NeutronClientException as e:
+            raise exception.NetworkException(
+                code=e.status_code, message=e.message)
+
     def show_router(self, router_id):
         try:
             return self.client.show_router(router_id).get('router', {})
