@@ -25,7 +25,9 @@ import manila.common.config
 import manila.compute
 import manila.compute.nova
 import manila.coordination
+import manila.data.drivers.nfs
 import manila.data.helper
+import manila.data.manager
 import manila.db.api
 import manila.db.base
 import manila.exception
@@ -81,6 +83,7 @@ import manila.share.drivers.qnap.qnap
 import manila.share.drivers.quobyte.quobyte
 import manila.share.drivers.service_instance
 import manila.share.drivers.tegile.tegile
+import manila.share.drivers.vastdata.driver
 import manila.share.drivers.windows.service_instance
 import manila.share.drivers.windows.winrm_helper
 import manila.share.drivers.zfsonlinux.driver
@@ -104,7 +107,10 @@ _global_opt_lists = [
     manila.common.config.global_opts,
     manila.compute._compute_opts,
     manila.coordination.coordination_opts,
+    manila.data.drivers.nfs.nfsbackup_service_opts,
     manila.data.helper.data_helper_opts,
+    manila.data.manager.backup_opts,
+    manila.data.manager.data_opts,
     manila.db.api.db_opts,
     [manila.db.base.db_driver_opt],
     manila.exception.exc_log_opts,
@@ -168,8 +174,10 @@ _global_opt_lists = [
     manila.share.drivers.netapp.options.netapp_connection_opts,
     manila.share.drivers.netapp.options.netapp_transport_opts,
     manila.share.drivers.netapp.options.netapp_basicauth_opts,
+    manila.share.drivers.netapp.options.netapp_certificateauth_opts,
     manila.share.drivers.netapp.options.netapp_provisioning_opts,
     manila.share.drivers.netapp.options.netapp_data_motion_opts,
+    manila.share.drivers.netapp.options.netapp_backup_opts,
     manila.share.drivers.nexenta.options.nexenta_connection_opts,
     manila.share.drivers.nexenta.options.nexenta_dataset_opts,
     manila.share.drivers.nexenta.options.nexenta_nfs_opts,
@@ -190,6 +198,7 @@ _global_opt_lists = [
     manila.share.manager.share_manager_opts,
     manila.volume._volume_opts,
     manila.wsgi.eventlet_server.socket_opts,
+    manila.share.drivers.vastdata.driver.OPTS,
 ]
 
 _opts = [
