@@ -22,58 +22,96 @@ from oslo_config import cfg
 from oslo_log import log
 from oslo_utils import importutils
 from oslo_utils import timeutils
-import six
 
 from manila import db
 from manila import exception
 
 LOG = log.getLogger(__name__)
 
+QUOTA_GROUP = 'quota'
+
 quota_opts = [
-    cfg.IntOpt('quota_shares',
+    cfg.IntOpt('shares',
                default=50,
-               help='Number of shares allowed per project.'),
-    cfg.IntOpt('quota_snapshots',
+               help='Number of shares allowed per project.',
+               deprecated_group='DEFAULT',
+               deprecated_name='quota_shares'),
+    cfg.IntOpt('snapshots',
                default=50,
-               help='Number of share snapshots allowed per project.'),
-    cfg.IntOpt('quota_gigabytes',
+               help='Number of share snapshots allowed per project.',
+               deprecated_group='DEFAULT',
+               deprecated_name='quota_snapshots'),
+    cfg.IntOpt('gigabytes',
                default=1000,
-               help='Number of share gigabytes allowed per project.'),
-    cfg.IntOpt('quota_snapshot_gigabytes',
+               help='Number of share gigabytes allowed per project.',
+               deprecated_group='DEFAULT',
+               deprecated_name='quota_gigabytes'),
+    cfg.IntOpt('per_share_gigabytes',
+               default=-1,
+               help='Max size allowed per share, in gigabytes.',
+               deprecated_group='DEFAULT',
+               deprecated_name='quota_per_share_gigabytes'),
+    cfg.IntOpt('snapshot_gigabytes',
                default=1000,
-               help='Number of snapshot gigabytes allowed per project.'),
-    cfg.IntOpt('quota_share_networks',
+               help='Number of snapshot gigabytes allowed per project.',
+               deprecated_group='DEFAULT',
+               deprecated_name='quota_snapshot_gigabytes'),
+    cfg.IntOpt('share_networks',
                default=10,
-               help='Number of share-networks allowed per project.'),
-    cfg.IntOpt('quota_share_replicas',
+               help='Number of share-networks allowed per project.',
+               deprecated_group='DEFAULT',
+               deprecated_name='quota_share_networks'),
+    cfg.IntOpt('share_replicas',
                default=100,
-               help='Number of share-replicas allowed per project.'),
-    cfg.IntOpt('quota_replica_gigabytes',
+               help='Number of share-replicas allowed per project.',
+               deprecated_group='DEFAULT',
+               deprecated_name='quota_share_replicas'),
+    cfg.IntOpt('replica_gigabytes',
                default=1000,
-               help='Number of replica gigabytes allowed per project.'),
-
-    cfg.IntOpt('quota_share_groups',
+               help='Number of replica gigabytes allowed per project.',
+               deprecated_group='DEFAULT',
+               deprecated_name='quota_replica_gigabytes'),
+    cfg.IntOpt('share_groups',
                default=50,
-               help='Number of share groups allowed.'),
-    cfg.IntOpt('quota_share_group_snapshots',
+               help='Number of share groups allowed.',
+               deprecated_group='DEFAULT',
+               deprecated_name='quota_share_groups'),
+    cfg.IntOpt('share_group_snapshots',
                default=50,
-               help='Number of share group snapshots allowed.'),
-
+               help='Number of share group snapshots allowed.',
+               deprecated_group='DEFAULT',
+               deprecated_name='quota_share_group_snapshots'),
     cfg.IntOpt('reservation_expire',
                default=86400,
-               help='Number of seconds until a reservation expires.'),
+               help='Number of seconds until a reservation expires.',
+               deprecated_group='DEFAULT'),
     cfg.IntOpt('until_refresh',
                default=0,
-               help='Count of reservations until usage is refreshed.'),
+               help='Count of reservations until usage is refreshed.',
+               deprecated_group='DEFAULT'),
     cfg.IntOpt('max_age',
                default=0,
-               help='Number of seconds between subsequent usage refreshes.'),
-    cfg.StrOpt('quota_driver',
+               help='Number of seconds between subsequent usage refreshes.',
+               deprecated_group='DEFAULT'),
+    cfg.StrOpt('driver',
                default='manila.quota.DbQuotaDriver',
-               help='Default driver to use for quota checks.'), ]
+               help='Default driver to use for quota checks.',
+               deprecated_group='DEFAULT',
+               deprecated_name='quota_driver'),
+    cfg.IntOpt('backups',
+               default=10,
+               help='Number of share backups allowed per project.',
+               deprecated_group='DEFAULT',
+               deprecated_name='quota_backups'),
+    cfg.IntOpt('backup_gigabytes',
+               default=1000,
+               help='Total amount of storage, in gigabytes, allowed '
+               'for backups per project.',
+               deprecated_group='DEFAULT',
+               deprecated_name='quota_backup_gigabytes'), ]
 
 CONF = cfg.CONF
-CONF.register_opts(quota_opts)
+CONF.register_opts(quota_opts, QUOTA_GROUP)
 
 
 class DbQuotaDriver(object):
@@ -383,6 +421,50 @@ class DbQuotaDriver(object):
 
         return {k: v['limit'] for k, v in quotas.items()}
 
+    def limit_check(self, context, resources, values, project_id=None):
+        """Check simple quota limits.
+
+        For limits--those quotas for which there is no usage
+        synchronization function--this method checks that a set of
+        proposed values are permitted by the limit restriction.
+
+        This method will raise a QuotaResourceUnknown exception if a
+        given resource is unknown or if it is not a simple limit
+        resource.
+
+        If any of the proposed values is over the defined quota, an
+        OverQuota exception will be raised with the sorted list of the
+        resources which are too high.  Otherwise, the method returns
+        nothing.
+
+        :param context: The request context, for access checks.
+        :param resources: A dictionary of the registered resources.
+        :param values: A dictionary of the values to check against the
+                       quota.
+        :param project_id: Specify the project_id if current context
+                           is admin and admin wants to impact on
+                           common user's tenant.
+        """
+
+        # Ensure no value is less than zero
+        unders = [key for key, val in values.items() if val < 0]
+        if unders:
+            raise exception.InvalidQuotaValue(unders=sorted(unders))
+
+        # If project_id is None, then we use the project_id in context
+        if project_id is None:
+            project_id = context.project_id
+
+        quotas = self._get_quotas(context, resources, values.keys(),
+                                  has_sync=False, project_id=project_id)
+        # Check the quotas and construct a list of the resources that
+        # would be put over limit by the desired values
+        overs = [key for key, val in values.items()
+                 if quotas[key] >= 0 and quotas[key] < val]
+        if overs:
+            raise exception.OverQuota(overs=sorted(overs), quotas=quotas,
+                                      usages={})
+
     def reserve(self, context, resources, deltas, expire=None,
                 project_id=None, user_id=None, share_type_id=None,
                 overquota_allowed=False):
@@ -426,8 +508,8 @@ class DbQuotaDriver(object):
 
         # Set up the reservation expiration
         if expire is None:
-            expire = CONF.reservation_expire
-        if isinstance(expire, six.integer_types):
+            expire = CONF.quota.reservation_expire
+        if isinstance(expire, int):
             expire = datetime.timedelta(seconds=expire)
         if isinstance(expire, datetime.timedelta):
             expire = timeutils.utcnow() + expire
@@ -464,7 +546,7 @@ class DbQuotaDriver(object):
         #            have to do the work there.
         return db.quota_reserve(
             context, resources, quotas, user_quotas, share_type_quotas,
-            deltas, expire, CONF.until_refresh, CONF.max_age,
+            deltas, expire, CONF.quota.until_refresh, CONF.quota.max_age,
             project_id=project_id, user_id=user_id,
             share_type_id=share_type_id, overquota_allowed=overquota_allowed)
 
@@ -622,7 +704,7 @@ class BaseResource(object):
     def default(self):
         """Return the default value of the quota."""
 
-        return CONF[self.flag] if self.flag else -1
+        return CONF.quota[self.flag] if self.flag else -1
 
 
 class ReservableResource(BaseResource):
@@ -657,7 +739,8 @@ class ReservableResource(BaseResource):
         """
 
         super(ReservableResource, self).__init__(name, flag=flag)
-        self.sync = sync
+        if sync:
+            self.sync = sync
 
 
 class AbsoluteResource(BaseResource):
@@ -720,8 +803,8 @@ class QuotaEngine(object):
         if self.__driver:
             return self.__driver
         if not self._driver_cls:
-            self._driver_cls = CONF.quota_driver
-        if isinstance(self._driver_cls, six.string_types):
+            self._driver_cls = CONF.quota.driver
+        if isinstance(self._driver_cls, str):
             self._driver_cls = importutils.import_object(self._driver_cls)
         self.__driver = self._driver_cls
         return self.__driver
@@ -876,6 +959,34 @@ class QuotaEngine(object):
 
         return res.count(context, *args, **kwargs)
 
+    def limit_check(self, context, project_id=None, **values):
+        """Check simple quota limits.
+
+        For limits--those quotas for which there is no usage
+        synchronization function--this method checks that a set of
+        proposed values are permitted by the limit restriction.  The
+        values to check are given as keyword arguments, where the key
+        identifies the specific quota limit to check, and the value is
+        the proposed value.
+
+        This method will raise a QuotaResourceUnknown exception if a
+        given resource is unknown or if it is not a simple limit
+        resource.
+
+        If any of the proposed values is over the defined quota, an
+        OverQuota exception will be raised with the sorted list of the
+        resources which are too high.  Otherwise, the method returns
+        nothing.
+
+        :param context: The request context, for access checks.
+        :param project_id: Specify the project_id if current context
+                           is admin and admin wants to impact on
+                           common user's tenant.
+        """
+
+        return self._driver.limit_check(context, self._resources, values,
+                                        project_id=project_id)
+
     def reserve(self, context, expire=None, project_id=None, user_id=None,
                 share_type_id=None, overquota_allowed=False, **deltas):
         """Check quotas and reserve resources.
@@ -1056,21 +1167,26 @@ QUOTAS = QuotaEngine()
 
 
 resources = [
-    ReservableResource('shares', '_sync_shares', 'quota_shares'),
-    ReservableResource('snapshots', '_sync_snapshots', 'quota_snapshots'),
-    ReservableResource('gigabytes', '_sync_gigabytes', 'quota_gigabytes'),
+    ReservableResource('shares', '_sync_shares', 'shares'),
+    ReservableResource('snapshots', '_sync_snapshots', 'snapshots'),
+    ReservableResource('gigabytes', '_sync_gigabytes', 'gigabytes'),
+    ReservableResource('per_share_gigabytes', None,
+                       'per_share_gigabytes'),
     ReservableResource('snapshot_gigabytes', '_sync_snapshot_gigabytes',
-                       'quota_snapshot_gigabytes'),
+                       'snapshot_gigabytes'),
     ReservableResource('share_networks', '_sync_share_networks',
-                       'quota_share_networks'),
+                       'share_networks'),
     ReservableResource('share_groups', '_sync_share_groups',
-                       'quota_share_groups'),
+                       'share_groups'),
     ReservableResource('share_group_snapshots', '_sync_share_group_snapshots',
-                       'quota_share_group_snapshots'),
+                       'share_group_snapshots'),
     ReservableResource('share_replicas', '_sync_share_replicas',
-                       'quota_share_replicas'),
+                       'share_replicas'),
     ReservableResource('replica_gigabytes', '_sync_replica_gigabytes',
-                       'quota_replica_gigabytes'),
+                       'replica_gigabytes'),
+    ReservableResource('backups', '_sync_backups', 'backups'),
+    ReservableResource('backup_gigabytes', '_sync_backup_gigabytes',
+                       'backup_gigabytes')
 ]
 
 
