@@ -14,13 +14,14 @@
 #    under the License.
 
 import os
-import pipes
+import shlex
 
 from oslo_concurrency import processutils
 from oslo_log import log
 
 from manila import exception
 from manila.i18n import _
+from manila import ssh_utils
 from manila import utils
 
 LOG = log.getLogger(__name__)
@@ -63,7 +64,7 @@ class SSHExecutor(object):
     """Callable encapsulating exec through ssh."""
 
     def __init__(self, *args, **kwargs):
-        self.pool = utils.SSHPool(*args, **kwargs)
+        self.pool = ssh_utils.SSHPool(*args, **kwargs)
 
     def __call__(self, *args, **kwargs):
         # argument with identifier 'run_as_root=' is not accepted by
@@ -71,7 +72,7 @@ class SSHExecutor(object):
         # method. So implement workaround to enable or disable 'run as root'
         # behavior.
         run_as_root = kwargs.pop('run_as_root', False)
-        cmd = ' '.join(pipes.quote(a) for a in args)
+        cmd = ' '.join(shlex.quote(a) for a in args)
         if run_as_root:
             cmd = ' '.join(['sudo', cmd])
         ssh = self.pool.get()
@@ -147,7 +148,7 @@ def fixup_access_rule(access_rule):
     :return: access_rule
     """
     if access_rule['access_to'] == '0.0.0.0/0':
-        access_rule['access_to'] = '0.0.0.0'
+        access_rule['access_to'] = '0.0.0.0'  # nosec B104
         LOG.debug("Set access_to field to '0.0.0.0' in ganesha back end.")
 
     return access_rule
