@@ -45,6 +45,7 @@ class NetAppCmodeMultiSvmShareDriver(driver.ShareDriver):
         # NetApp driver supports multiple subnets including update existing
         # share servers.
         self.network_allocation_update_support = True
+        self.share_replicas_migration_support = True
 
     def do_setup(self, context):
         self.library.do_setup(context)
@@ -110,9 +111,9 @@ class NetAppCmodeMultiSvmShareDriver(driver.ShareDriver):
         self.library.unmanage_snapshot(snapshot, share_server=share_server)
 
     def update_access(self, context, share, access_rules, add_rules,
-                      delete_rules, **kwargs):
+                      delete_rules, update_rules, **kwargs):
         self.library.update_access(context, share, access_rules, add_rules,
-                                   delete_rules, **kwargs)
+                                   delete_rules, update_rules, **kwargs)
 
     def _update_share_stats(self, data=None):
         data = self.library.get_share_stats(
@@ -403,3 +404,11 @@ class NetAppCmodeMultiSvmShareDriver(driver.ShareDriver):
                                    share_server=None):
         self.library.update_share_from_metadata(
             context, share, metadata, share_server=share_server)
+
+    def update_share_network_subnet_from_metadata(self, context,
+                                                  share_network,
+                                                  share_network_subnet,
+                                                  share_server, metadata):
+        self.library.update_share_network_subnet_from_metadata(
+            context, share_network, share_network_subnet,
+            share_server, metadata)
