@@ -37,7 +37,15 @@ netapp_connection_opts = [
     cfg.PortOpt('netapp_server_port',
                 help=('The TCP port to use for communication with the storage '
                       'system or proxy server. If not specified, Data ONTAP '
-                      'drivers will use 80 for HTTP and 443 for HTTPS.')), ]
+                      'drivers will use 80 for HTTP and 443 for HTTPS.')),
+    cfg.BoolOpt('netapp_use_legacy_client',
+                default=True,
+                help=('The ONTAP client used for retrieving and modifying '
+                      'data on the storage. The legacy client relies mostly '
+                      'on ZAPI calls, only using REST calls for SVM migrate '
+                      'feature. If set to False, the new REST client is used, '
+                      'which runs REST calls if supported, otherwise falls '
+                      'back to the equivalent ZAPI call.')), ]
 
 netapp_transport_opts = [
     cfg.StrOpt('netapp_transport_type',
@@ -63,6 +71,64 @@ netapp_basicauth_opts = [
                      'specified in the netapp_login option.'),
                secret=True), ]
 
+netapp_certificateauth_opts = [
+    cfg.StrOpt('netapp_private_key_file',
+               help=('Example: /path/to/private_key.key,'
+                     ' For self signed certificate: This file contains the'
+                     ' private key associated with the self-signed'
+                     ' certificate. It is a sensitive file that should be'
+                     ' kept secure and protected. The private key is used to'
+                     ' sign the certificate and establish the authenticity'
+                     ' and integrity of the certificate during the'
+                     ' authentication process.'
+                     ' For ca verified certificate: This file contains the'
+                     ' private key associated with the certificate. It is'
+                     ' generated when creating the certificate signing'
+                     ' request (CSR) and should be kept secure and protected.'
+                     ' The private key is used to sign the CSR and later used'
+                     ' to establish secure connections and authenticate the'
+                     ' entity.'
+                     ' Please provide absolute path.'),
+               secret=True),
+    cfg.StrOpt('netapp_certificate_file',
+               help=('Example: /path/to/certificate.pem or'
+                     ' /path/to/certificate.crt,'
+                     ' For self signed certificate: This file contains the'
+                     ' self-signed digital certificate itself. It includes'
+                     ' information about the entity such as the common name'
+                     ' (e.g., domain name), organization details, validity'
+                     ' period, and public key. The certificate file is'
+                     ' generated based on the private key and is used by'
+                     ' clients or systems to verify the entity identity'
+                     ' during the authentication process.'
+                     ' For ca verified certificate: This file contains the'
+                     ' digital certificate issued by the trusted third-party'
+                     ' certificate authority (CA). It includes information'
+                     ' about the entity identity, public key, and the CA that'
+                     ' issued the certificate. The certificate file is used'
+                     ' by clients or systems to verify the authenticity and'
+                     ' integrity of the entity during the authentication'
+                     ' process.'
+                     ' Please provide absolute path.'),
+               secret=True),
+    cfg.StrOpt('netapp_ca_certificate_file',
+               help=('This is applicable only for ca verified certificate.'
+                     'Example: /path/to/ca_certificate.crt, This file'
+                     ' contains the public key certificate of the trusted'
+                     ' third-party certificate authority (CA) that issued the'
+                     ' certificate. It is used by clients or systems to'
+                     ' validate the authenticity of the certificate'
+                     ' presented by the entity. The CA certificate file'
+                     ' is typically pre-configured in the trust store'
+                     ' of clients or systems to establish trust in'
+                     ' certificates issued by that CA.'
+                     ' Please provide absolute path.'),
+               secret=True),
+    cfg.BoolOpt('netapp_certificate_host_validation',
+                default=False,
+                help=('By default certificate verification is disabled and '
+                      'to verify please assign True to this option')), ]
+
 netapp_provisioning_opts = [
     cfg.ListOpt('netapp_enabled_share_protocols',
                 default=['nfs3', 'nfs4.0'],
@@ -99,6 +165,11 @@ netapp_provisioning_opts = [
     cfg.StrOpt('netapp_root_volume',
                default='root',
                help='Root volume name.'),
+    cfg.IntOpt('netapp_delete_retention_hours',
+               min=0,
+               default=12,
+               help='The number of hours that a deleted volume should be '
+                    'retained before the delete is completed.'),
     cfg.IntOpt('netapp_volume_snapshot_reserve_percent',
                min=0,
                max=90,
@@ -176,7 +247,29 @@ netapp_provisioning_opts = [
                min=60,
                default=360,  # Default to six minutes
                help='Sets time in seconds to wait for a FlexGroup snapshot '
-                    'to not be busy with clones after splitting them.'), ]
+                    'to not be busy with clones after splitting them.'),
+    cfg.IntOpt('netapp_rest_operation_timeout',
+               min=60,
+               default=60,  # Default to one minutes
+               help='Sets maximum amount of time in seconds to wait for a '
+                    'synchronous ONTAP REST API operation to be completed.'),
+    cfg.IntOpt('netapp_security_cert_expire_days',
+               min=1,
+               max=3652,
+               default=365,
+               help='Defines the expiration time (in days) for the '
+                    'certificate created during the vserver creation.  This '
+                    'option only applies when the option '
+                    'driver_handles_share_servers is set to True.'),
+    cfg.BoolOpt('netapp_restrict_lif_creation_per_ha_pair',
+                default=False,
+                help='Prevent the creation of a share server if total number'
+                     ' of data LIFs on one node of HA pair, including those'
+                     ' that can be migrated in case of failure, exceeds the '
+                     'maximum data LIFs supported by the node. This option '
+                     'guarantees that, in the event of a node failure, the'
+                     ' partner node will be able to takeover all data LIFs.')
+]
 
 netapp_cluster_opts = [
     cfg.StrOpt('netapp_vserver',
@@ -186,7 +279,12 @@ netapp_cluster_opts = [
                      'option should only be specified when the option '
                      'driver_handles_share_servers is set to False (i.e. the '
                      'driver is managing shares on a single pre-configured '
-                     'Vserver).')), ]
+                     'Vserver).')),
+    cfg.StrOpt('netapp_cluster_name',
+               help=('This option specifies the Cluster Name on which '
+                     'provisioning of file storage shares should occur. '
+                     'If not set, the driver will try to discover by '
+                     'API call.')), ]
 
 netapp_support_opts = [
     cfg.StrOpt('netapp_trace_flags',
@@ -215,12 +313,14 @@ netapp_data_motion_opts = [
                default=3600,  # One Hour
                help='The maximum time in seconds to wait for a snapmirror '
                     'release when breaking snapmirror relationships.'),
-    cfg.IntOpt('netapp_snapmirror_last_transfer_size_limit',
-               min=512,
-               default=1024,  # One MB
-               help='This option set the last transfer size limit (in KB) '
-                    'of snapmirror to decide whether replica is in sync or '
-                    'out of sync.'),
+    cfg.StrOpt('netapp_snapmirror_schedule',
+               default='hourly',  # One Hour
+               help='An interval in either minutes or hours used to update '
+                    'the SnapMirror relationship. Few valid values are: '
+                    '5min, 10min, 30min, hourly etc. The schedule at the '
+                    '"destination" host will be the one that will be '
+                    'considered when creating a new replica, or promoting '
+                    'a replica'),
     cfg.IntOpt('netapp_volume_move_cutover_timeout',
                min=0,
                default=3600,  # One Hour,
@@ -265,11 +365,49 @@ netapp_data_motion_opts = [
                     'a replica.'),
 ]
 
+netapp_backup_opts = [
+    cfg.ListOpt('netapp_enabled_backup_types',
+                default=[],
+                help='Specify compatible backup_types for backend to provision'
+                     ' backup share for SnapVault relationship. Multiple '
+                     'backup_types can be provided. If multiple backup types '
+                     'are enabled, create separate config sections for each '
+                     'backup type specifying the "netapp_backup_vserver", '
+                     '"netapp_backup_backend_section_name", '
+                     '"netapp_backup_volume", and '
+                     '"netapp_snapmirror_job_timeout" as appropriate.'
+                     ' Example- netapp_enabled_backup_types = eng_backup,'
+                     ' finance_backup'),
+    cfg.StrOpt('netapp_backup_backend_section_name',
+               help='Backend (ONTAP cluster) name where backup volume will be '
+                    'provisioned. This is one of the backend which is enabled '
+                    'in manila.conf file.'),
+    cfg.StrOpt('netapp_backup_vserver',
+               default='',
+               help='vserver name of backend that is use for backup the share.'
+                    ' When user provide vserver value then backup volume will '
+                    ' be created under this vserver '),
+    cfg.StrOpt('netapp_backup_volume',
+               default='',
+               help='Specify backup share name in case user wanted to backup '
+                    'the share. Some case user has dedicated volume for backup'
+                    ' in this case use can provide dedicated volume. '
+                    'backup_share_server must be specified if backup_share is'
+                    ' provided'),
+    cfg.IntOpt('netapp_snapmirror_job_timeout',
+               min=0,
+               default=1800,  # 30 minutes
+               help='The maximum time in seconds to wait for a snapmirror '
+                    'related operation to backup to complete.'),
+]
+
 CONF = cfg.CONF
 CONF.register_opts(netapp_proxy_opts)
 CONF.register_opts(netapp_connection_opts)
 CONF.register_opts(netapp_transport_opts)
 CONF.register_opts(netapp_basicauth_opts)
+CONF.register_opts(netapp_certificateauth_opts)
 CONF.register_opts(netapp_provisioning_opts)
 CONF.register_opts(netapp_support_opts)
 CONF.register_opts(netapp_data_motion_opts)
+CONF.register_opts(netapp_backup_opts)
