@@ -18,7 +18,6 @@
 
 import abc
 import os
-import socket
 import time
 
 import netaddr
@@ -30,11 +29,13 @@ from oslo_utils import netutils
 from manila.common import constants as const
 from manila import compute
 from manila import context
+from manila import coordination
 from manila import exception
 from manila.i18n import _
 from manila import image
 from manila.network.linux import ip_lib
 from manila.network.neutron import api as neutron
+from manila import ssh_utils
 from manila import utils
 
 LOG = log.getLogger(__name__)
@@ -225,7 +226,6 @@ class ServiceInstanceManager(object):
             raise exception.ServiceInstanceException(
                 _('Service instance user is not specified.'))
         self.admin_context = context.get_admin_context()
-        self._execute = utils.execute
 
         self.image_api = image.API()
         self.compute_api = compute.API()
@@ -498,6 +498,11 @@ class ServiceInstanceManager(object):
                 instance_details.pop(key)
         return instance_details
 
+    def _load_public_key(self, path):
+        with open(path, 'r') as f:
+            public_key = f.read()
+        return public_key
+
     @utils.synchronized("service_instance_get_key", external=True)
     def _get_key(self, context):
         """Get ssh key.
@@ -518,7 +523,7 @@ class ServiceInstanceManager(object):
         if len(keypairs) > 1:
             raise exception.ServiceInstanceException(_('Ambiguous keypairs.'))
 
-        public_key, __ = self._execute('cat', path_to_public_key)
+        public_key = self._load_public_key(path_to_public_key)
         if not keypairs:
             keypair = self.compute_api.keypair_import(
                 context, keypair_name, public_key)
@@ -658,27 +663,36 @@ class ServiceInstanceManager(object):
         """
         return {}
 
-    def _check_server_availability(self, instance_details):
+    def _check_server_availability(self, instance_details, interval=5):
         t = time.time()
+        ssh_pool = ssh_utils.SSHPool(instance_details['ip'],
+                                     22,
+                                     interval,
+                                     instance_details['username'],
+                                     instance_details.get('password'),
+                                     instance_details.get('pk_path'),
+                                     max_size=1)
         while time.time() - t < self.max_time_to_build_instance:
             LOG.debug('Checking server availability.')
-            if not self._test_server_connection(instance_details):
-                time.sleep(5)
+            if not self._test_server_connection(instance_details, ssh_pool):
+                time.sleep(interval)
             else:
                 return True
         return False
 
-    def _test_server_connection(self, server):
+    def _test_server_connection(self, server, ssh_pool):
+        conn = None
         try:
-            socket.socket().connect((server['ip'], 22))
-            LOG.debug('Server %s is available via SSH.',
-                      server['ip'])
+            conn = ssh_pool.create(quiet=True)
             return True
-        except socket.error as e:
+        except Exception as e:
             LOG.debug(e)
-            LOG.debug("Server %s is not available via SSH. Waiting...",
-                      server['ip'])
+            LOG.debug("Could not login to server %s over SSH. Waiting...",
+                      server["ip"])
             return False
+        finally:
+            if conn:
+                conn.close()
 
     def delete_service_instance(self, context, server_details):
         """Removes share infrastructure.
@@ -814,7 +828,7 @@ class NeutronNetworkHelper(BaseNetworkhelper):
         net = self.neutron_api.get_network(network_info['neutron_net_id'])
         return net['name']
 
-    @utils.synchronized("service_instance_get_service_network", external=True)
+    @coordination.synchronized("service_instance_get_service_network")
     def _get_service_network_id(self):
         """Finds existing or creates new service network."""
         service_network_name = self.get_config_option("service_network_name")
