@@ -171,6 +171,9 @@ class TegileShareDriver(driver.ShareDriver):
     def __init__(self, *args, **kwargs):
         super(TegileShareDriver, self).__init__(False, *args, **kwargs)
 
+        LOG.warning('Tegile share driver has been deprecated and will be '
+                    'removed in a future release.')
+
         self.configuration.append_config_values(tegile_opts)
         self._default_project = (self.configuration.safe_get(
             "tegile_default_project") or 'openstack')
@@ -399,7 +402,7 @@ class TegileShareDriver(driver.ShareDriver):
 
     @debugger
     def update_access(self, context, share, access_rules, add_rules,
-                      delete_rules, share_server=None):
+                      delete_rules, update_rules, share_server=None):
         if not (add_rules or delete_rules):
             # Recovery mode
             pool, project, share_name = (
