@@ -79,6 +79,18 @@ class ShareAPI(object):
         1.20 - Add share_instance_id parameter for create_share_server() method
         1.21 - Add share_server_migration_start, share_server_migration_check()
             and share_server_get_progress()
+        1.22 - Add update_share_network_security_service() and
+            check_update_share_network_security_service()
+        1.23 - Add update_share_server_network_allocations() and
+            check_update_share_server_network_allocations()
+        1.24 - Add quiesce_wait_time paramater to promote_share_replica()
+        1.25 - Add transfer_accept()
+        1.26 - Add create_backup() and delete_backup()
+            restore_backup() methods
+        1.27 - Update delete_share_instance() and delete_snapshot() methods
+        1.28 - Add update_share_from_metadata() method
+        1.29 - Add ensure_shares()
+        1.30 - Add update_share_network_subnet_from_metadata() method
     """
 
     BASE_RPC_API_VERSION = '1.0'
@@ -87,7 +99,7 @@ class ShareAPI(object):
         super(ShareAPI, self).__init__()
         target = messaging.Target(topic=CONF.share_topic,
                                   version=self.BASE_RPC_API_VERSION)
-        self.client = rpc.get_client(target, version_cap='1.21')
+        self.client = rpc.get_client(target, version_cap='1.30')
 
     def create_share_instance(self, context, share_instance, host,
                               request_spec, filter_properties,
@@ -155,13 +167,15 @@ class ShareAPI(object):
                           snapshot_id=snapshot['id'],
                           reservations=reservations)
 
-    def delete_share_instance(self, context, share_instance, force=False):
+    def delete_share_instance(self, context, share_instance, force=False,
+                              deferred_delete=False):
         host = utils.extract_host(share_instance['host'])
-        call_context = self.client.prepare(server=host, version='1.4')
+        call_context = self.client.prepare(server=host, version='1.27')
         call_context.cast(context,
                           'delete_share_instance',
                           share_instance_id=share_instance['id'],
-                          force=force)
+                          force=force,
+                          deferred_delete=deferred_delete)
 
     def migration_start(self, context, share, dest_host,
                         force_host_assisted_migration, preserve_metadata,
@@ -262,13 +276,15 @@ class ShareAPI(object):
                           share_id=share['id'],
                           snapshot_id=snapshot['id'])
 
-    def delete_snapshot(self, context, snapshot, host, force=False):
+    def delete_snapshot(self, context, snapshot, host, force=False,
+                        deferred_delete=False):
         new_host = utils.extract_host(host)
-        call_context = self.client.prepare(server=new_host)
+        call_context = self.client.prepare(server=new_host, version='1.27')
         call_context.cast(context,
                           'delete_snapshot',
                           snapshot_id=snapshot['id'],
-                          force=force)
+                          force=force,
+                          deferred_delete=deferred_delete)
 
     def create_replicated_snapshot(self, context, share, replicated_snapshot):
         host = utils.extract_host(share['instance']['host'])
@@ -306,6 +322,18 @@ class ShareAPI(object):
         call_context = self.client.prepare(fanout=True, version='1.0')
         call_context.cast(context, 'publish_service_capabilities')
 
+    def transfer_accept(self, ctxt, share, new_user,
+                        new_project, clear_rules=False):
+        msg_args = {
+            'share_id': share['id'],
+            'new_user': new_user,
+            'new_project': new_project,
+            'clear_rules': clear_rules
+        }
+        host = utils.extract_host(share['instance']['host'])
+        call_context = self.client.prepare(server=host, version='1.25')
+        call_context.call(ctxt, 'transfer_accept', **msg_args)
+
     def extend_share(self, context, share, new_size, reservations):
         host = utils.extract_host(share['instance']['host'])
         call_context = self.client.prepare(server=host, version='1.2')
@@ -370,13 +398,15 @@ class ShareAPI(object):
                           share_id=share_replica['share_id'],
                           force=force)
 
-    def promote_share_replica(self, context, share_replica):
+    def promote_share_replica(self, context, share_replica,
+                              quiesce_wait_time=None):
         host = utils.extract_host(share_replica['host'])
-        call_context = self.client.prepare(server=host, version='1.8')
+        call_context = self.client.prepare(server=host, version='1.24')
         call_context.cast(context,
                           'promote_share_replica',
                           share_replica_id=share_replica['id'],
-                          share_id=share_replica['share_id'])
+                          share_id=share_replica['share_id'],
+                          quiesce_wait_time=quiesce_wait_time)
 
     def update_share_replica(self, context, share_replica):
         host = utils.extract_host(share_replica['host'])
@@ -436,3 +466,103 @@ class ShareAPI(object):
         call_context.cast(context,
                           'snapshot_update_access',
                           snapshot_instance_id=snapshot_instance['id'])
+
+    def update_share_network_security_service(
+            self, context, dest_host, share_network_id,
+            new_security_service_id, current_security_service_id=None):
+        host = utils.extract_host(dest_host)
+        call_context = self.client.prepare(server=host, version='1.22')
+        call_context.cast(
+            context,
+            'update_share_network_security_service',
+            share_network_id=share_network_id,
+            new_security_service_id=new_security_service_id,
+            current_security_service_id=current_security_service_id)
+
+    def check_update_share_network_security_service(
+            self, context, dest_host, share_network_id,
+            new_security_service_id, current_security_service_id=None):
+        host = utils.extract_host(dest_host)
+        call_context = self.client.prepare(server=host, version='1.22')
+        call_context.cast(
+            context,
+            'check_update_share_network_security_service',
+            share_network_id=share_network_id,
+            new_security_service_id=new_security_service_id,
+            current_security_service_id=current_security_service_id)
+
+    def check_update_share_server_network_allocations(
+            self, context, dest_host, share_network_id,
+            new_share_network_subnet):
+        host = utils.extract_host(dest_host)
+        call_context = self.client.prepare(server=host, version='1.23')
+        call_context.cast(
+            context,
+            'check_update_share_server_network_allocations',
+            share_network_id=share_network_id,
+            new_share_network_subnet=new_share_network_subnet)
+
+    def update_share_server_network_allocations(
+            self, context, dest_host, share_network_id,
+            new_share_network_subnet_id):
+        host = utils.extract_host(dest_host)
+        call_context = self.client.prepare(server=host, version='1.23')
+        call_context.cast(
+            context,
+            'update_share_server_network_allocations',
+            share_network_id=share_network_id,
+            new_share_network_subnet_id=new_share_network_subnet_id)
+
+    def create_backup(self, context, backup):
+        host = utils.extract_host(backup['host'])
+        call_context = self.client.prepare(server=host, version='1.26')
+        return call_context.cast(context,
+                                 'create_backup',
+                                 backup=backup)
+
+    def delete_backup(self, context, backup):
+        host = utils.extract_host(backup['host'])
+        call_context = self.client.prepare(server=host, version='1.26')
+        return call_context.cast(context,
+                                 'delete_backup',
+                                 backup=backup)
+
+    def restore_backup(self, context, backup, share_id):
+        host = utils.extract_host(backup['host'])
+        call_context = self.client.prepare(server=host, version='1.26')
+        return call_context.cast(context,
+                                 'restore_backup',
+                                 backup=backup,
+                                 share_id=share_id)
+
+    def update_share_from_metadata(self, context, share, metadata):
+        host = utils.extract_host(share['instance']['host'])
+        call_context = self.client.prepare(server=host, version='1.28')
+        return call_context.cast(context,
+                                 'update_share_from_metadata',
+                                 share_id=share['id'],
+                                 metadata=metadata)
+
+    def update_share_network_subnet_from_metadata(self, context,
+                                                  share_network_id,
+                                                  share_network_subnet_id,
+                                                  share_server,
+                                                  metadata):
+        host = utils.extract_host(share_server['host'])
+        call_context = self.client.prepare(server=host, version='1.30')
+        call_context.cast(
+            context,
+            'update_share_network_subnet_from_metadata',
+            share_network_id=share_network_id,
+            share_network_subnet_id=share_network_subnet_id,
+            share_server_id=share_server['id'],
+            metadata=metadata)
+
+    def ensure_driver_resources(self, context, host):
+        host = utils.extract_host(host)
+        call_context = self.client.prepare(server=host, version='1.29')
+        return call_context.cast(
+            context,
+            'ensure_driver_resources',
+            skip_backend_info_check=True
+        )
