@@ -55,7 +55,8 @@ SERVICE_STATES_NO_POOLS = {
                   create_share_from_snapshot_support=False,
                   revert_to_snapshot_support=True,
                   mount_snapshot_support=True,
-                  driver_handles_share_servers=False),
+                  driver_handles_share_servers=False,
+                  mount_point_name_support=False),
     'host2@back1': dict(share_backend_name='BBB',
                         total_capacity_gb=256, free_capacity_gb=100,
                         timestamp=None, reserved_percentage=0,
@@ -68,7 +69,8 @@ SERVICE_STATES_NO_POOLS = {
                         create_share_from_snapshot_support=True,
                         revert_to_snapshot_support=False,
                         mount_snapshot_support=False,
-                        driver_handles_share_servers=False),
+                        driver_handles_share_servers=False,
+                        mount_point_name_support=False),
     'host2@back2': dict(share_backend_name='CCC',
                         total_capacity_gb=10000, free_capacity_gb=700,
                         timestamp=None, reserved_percentage=0,
@@ -81,7 +83,8 @@ SERVICE_STATES_NO_POOLS = {
                         create_share_from_snapshot_support=True,
                         revert_to_snapshot_support=False,
                         mount_snapshot_support=False,
-                        driver_handles_share_servers=False),
+                        driver_handles_share_servers=False,
+                        mount_point_name_support=False),
 }
 
 SHARE_SERVICES_WITH_POOLS = [
@@ -124,7 +127,9 @@ SHARE_SERVICE_STATES_WITH_POOLS = {
                                   reserved_share_extend_percentage=0,
                                   provisioned_capacity_gb=10,
                                   max_over_subscription_ratio=1.0,
-                                  thin_provisioning=False)]),
+                                  thin_provisioning=False,
+                                  mount_point_name_support=False,
+                                  )]),
     'host2@BBB': dict(share_backend_name='BBB',
                       timestamp=None, reserved_percentage=0,
                       reserved_snapshot_percentage=0,
@@ -142,7 +147,9 @@ SHARE_SERVICE_STATES_WITH_POOLS = {
                                   reserved_share_extend_percentage=0,
                                   provisioned_capacity_gb=60,
                                   max_over_subscription_ratio=2.0,
-                                  thin_provisioning=True)]),
+                                  thin_provisioning=True,
+                                  mount_point_name_support=False,
+                                  )]),
     'host3@CCC': dict(share_backend_name='CCC',
                       timestamp=None, reserved_percentage=0,
                       reserved_snapshot_percentage=0,
@@ -160,7 +167,9 @@ SHARE_SERVICE_STATES_WITH_POOLS = {
                                   reserved_share_extend_percentage=0,
                                   provisioned_capacity_gb=100,
                                   max_over_subscription_ratio=20.0,
-                                  thin_provisioning=True)]),
+                                  thin_provisioning=True,
+                                  mount_point_name_support=False,
+                                  )]),
     'host4@DDD': dict(share_backend_name='DDD',
                       timestamp=None, reserved_percentage=0,
                       reserved_snapshot_percentage=0,
@@ -178,7 +187,9 @@ SHARE_SERVICE_STATES_WITH_POOLS = {
                                   reserved_share_extend_percentage=0,
                                   provisioned_capacity_gb=800,
                                   max_over_subscription_ratio=2.0,
-                                  thin_provisioning=True),
+                                  thin_provisioning=True,
+                                  mount_point_name_support=False,
+                                  ),
                              dict(pool_name='pool4b',
                                   total_capacity_gb=542,
                                   free_capacity_gb=442,
@@ -187,7 +198,9 @@ SHARE_SERVICE_STATES_WITH_POOLS = {
                                   reserved_share_extend_percentage=0,
                                   provisioned_capacity_gb=2000,
                                   max_over_subscription_ratio=10.0,
-                                  thin_provisioning=True)]),
+                                  thin_provisioning=True,
+                                  mount_point_name_support=False,
+                                  )]),
     'host5@EEE': dict(share_backend_name='EEE',
                       timestamp=None, reserved_percentage=0,
                       reserved_snapshot_percentage=0,
@@ -205,7 +218,9 @@ SHARE_SERVICE_STATES_WITH_POOLS = {
                                   reserved_share_extend_percentage=0,
                                   provisioned_capacity_gb=100,
                                   max_over_subscription_ratio=1.0,
-                                  thin_provisioning=False),
+                                  thin_provisioning=False,
+                                  mount_point_name_support=False,
+                                  ),
                              dict(pool_name='pool5b',
                                   total_capacity_gb=552,
                                   free_capacity_gb=452,
@@ -214,7 +229,9 @@ SHARE_SERVICE_STATES_WITH_POOLS = {
                                   reserved_share_extend_percentage=0,
                                   provisioned_capacity_gb=100,
                                   max_over_subscription_ratio=1.0,
-                                  thin_provisioning=False)]),
+                                  thin_provisioning=False,
+                                  mount_point_name_support=False,
+                                  )]),
     'host6@FFF': dict(share_backend_name='FFF',
                       timestamp=None, reserved_percentage=0,
                       reserved_snapshot_percentage=0,
@@ -232,7 +249,9 @@ SHARE_SERVICE_STATES_WITH_POOLS = {
                                   reserved_share_extend_percentage=0,
                                   provisioned_capacity_gb=100,
                                   max_over_subscription_ratio=1.0,
-                                  thin_provisioning=False),
+                                  thin_provisioning=False,
+                                  mount_point_name_support=False,
+                                  ),
                              dict(pool_name='pool6b',
                                   total_capacity_gb='unknown',
                                   free_capacity_gb='unknown',
@@ -241,9 +260,171 @@ SHARE_SERVICE_STATES_WITH_POOLS = {
                                   reserved_share_extend_percentage=0,
                                   provisioned_capacity_gb=100,
                                   max_over_subscription_ratio=1.0,
-                                  thin_provisioning=False)]),
+                                  thin_provisioning=False,
+                                  mount_point_name_support=False,
+                                  )]),
 }
 
+FAKE_ACTIVE_IQ_WEIGHER_LIST = [
+    "fake_aggregate_1:fake_cluster_name1",
+    "fake_aggregate_2:fake_cluster_name2",
+    "fake_aggregate_3:fake_cluster_name3"
+]
+
+FAKE_ACTIVE_IQ_WEIGHER_AGGREGATES_RESPONSE = {
+    "records": [
+        {
+            "name": "fake_aggregate_1",
+            "key": "fake_key_1",
+            "cluster": {
+                "name": "fake_cluster_name1"
+            }
+        },
+        {
+            "name": "fake_aggregate_2",
+            "key": "fake_key_2",
+            "cluster": {
+                "name": "fake_cluster_name2"
+            }
+        },
+        {
+            "name": "fake_aggregate_3",
+            "key": "fake_key_3",
+            "cluster": {
+                "name": "fake_cluster_name3"
+            }
+        }
+    ]
+}
+
+FAKE_ACTIVE_IQ_WEIGHER_BALANCE_RESPONSE = [
+    {
+        "key": "fake_key_1",
+        "scores": {
+            "total_weighted_score": 10.0
+        }
+    },
+    {
+        "key": "fake_key_2",
+        "scores": {
+            "total_weighted_score": 20.0
+        }
+    }
+]
+
+
+class FakeHostManagerNetAppOnly(host_manager.HostManager):
+    def __init__(self):
+        super(FakeHostManagerNetAppOnly, self).__init__()
+
+        self.service_states = {
+            'host1': {
+                'total_capacity_gb': 1024,
+                'free_capacity_gb': 1024,
+                'allocated_capacity_gb': 0,
+                'thin_provisioning': False,
+                'reserved_percentage': 10,
+                'reserved_snapshot_percentage': 5,
+                'reserved_share_extend_percentage': 15,
+                'timestamp': None,
+                'snapshot_support': True,
+                'create_share_from_snapshot_support': True,
+                'replication_type': 'writable',
+                'replication_domain': 'endor',
+                'storage_protocol': 'NFS_CIFS',
+                'vendor_name': 'NetApp',
+                'netapp_cluster_name': 'cluster1',
+            },
+            'host2': {
+                'total_capacity_gb': 2048,
+                'free_capacity_gb': 300,
+                'allocated_capacity_gb': 1748,
+                'provisioned_capacity_gb': 1748,
+                'max_over_subscription_ratio': 2.0,
+                'thin_provisioning': True,
+                'reserved_percentage': 10,
+                'reserved_snapshot_percentage': 5,
+                'reserved_share_extend_percentage': 15,
+                'timestamp': None,
+                'snapshot_support': True,
+                'create_share_from_snapshot_support': True,
+                'replication_type': 'readable',
+                'replication_domain': 'kashyyyk',
+                'storage_protocol': 'NFS_CIFS',
+                'vendor_name': 'NetApp',
+                'netapp_cluster_name': 'cluster2',
+            },
+            'host3': {
+                'total_capacity_gb': 512,
+                'free_capacity_gb': 256,
+                'allocated_capacity_gb': 256,
+                'provisioned_capacity_gb': 256,
+                'max_over_subscription_ratio': 2.0,
+                'thin_provisioning': [False],
+                'reserved_percentage': 0,
+                'reserved_snapshot_percentage': 0,
+                'reserved_share_extend_percentage': 0,
+                'snapshot_support': True,
+                'create_share_from_snapshot_support': True,
+                'timestamp': None,
+                'storage_protocol': 'NFS_CIFS',
+                'vendor_name': 'NetApp',
+                'netapp_cluster_name': 'cluster3',
+            },
+            'host4': {
+                'total_capacity_gb': 2048,
+                'free_capacity_gb': 200,
+                'allocated_capacity_gb': 1848,
+                'provisioned_capacity_gb': 1848,
+                'max_over_subscription_ratio': 1.0,
+                'thin_provisioning': [True],
+                'reserved_percentage': 5,
+                'reserved_snapshot_percentage': 2,
+                'reserved_share_extend_percentage': 5,
+                'timestamp': None,
+                'snapshot_support': True,
+                'create_share_from_snapshot_support': True,
+                'replication_type': 'dr',
+                'replication_domain': 'naboo',
+                'storage_protocol': 'NFS_CIFS',
+                'vendor_name': 'NetApp',
+                'netapp_cluster_name': 'cluster4',
+            },
+            'host5': {
+                'total_capacity_gb': 2048,
+                'free_capacity_gb': 500,
+                'allocated_capacity_gb': 1548,
+                'provisioned_capacity_gb': 1548,
+                'max_over_subscription_ratio': 1.5,
+                'thin_provisioning': [True, False],
+                'reserved_percentage': 5,
+                'reserved_snapshot_percentage': 2,
+                'reserved_share_extend_percentage': 5,
+                'timestamp': None,
+                'snapshot_support': True,
+                'create_share_from_snapshot_support': True,
+                'replication_type': None,
+                'storage_protocol': 'NFS_CIFS',
+                'vendor_name': 'NetApp',
+                'netapp_cluster_name': 'cluster5',
+            },
+            'host6': {
+                'total_capacity_gb': 'unknown',
+                'free_capacity_gb': 'unknown',
+                'allocated_capacity_gb': 1548,
+                'thin_provisioning': False,
+                'reserved_percentage': 5,
+                'reserved_snapshot_percentage': 2,
+                'reserved_share_extend_percentage': 5,
+                'snapshot_support': True,
+                'create_share_from_snapshot_support': True,
+                'timestamp': None,
+                'storage_protocol': 'GLUSTERFS',
+                'vendor_name': 'NetApp',
+                'netapp_cluster_name': 'cluster6',
+            },
+        }
+
 
 class FakeFilterScheduler(filter.FilterScheduler):
     def __init__(self, *args, **kwargs):
@@ -269,6 +450,7 @@ class FakeHostManager(host_manager.HostManager):
                       'replication_type': 'writable',
                       'replication_domain': 'endor',
                       'storage_protocol': 'NFS_CIFS',
+                      'vendor_name': 'Dummy',
                       },
             'host2': {'total_capacity_gb': 2048,
                       'free_capacity_gb': 300,
@@ -285,6 +467,7 @@ class FakeHostManager(host_manager.HostManager):
                       'replication_type': 'readable',
                       'replication_domain': 'kashyyyk',
                       'storage_protocol': 'NFS_CIFS',
+                      'vendor_name': 'Dummy',
                       },
             'host3': {'total_capacity_gb': 512,
                       'free_capacity_gb': 256,
@@ -299,6 +482,7 @@ class FakeHostManager(host_manager.HostManager):
                       'create_share_from_snapshot_support': True,
                       'timestamp': None,
                       'storage_protocol': 'NFS_CIFS',
+                      'vendor_name': 'Dummy',
                       },
             'host4': {'total_capacity_gb': 2048,
                       'free_capacity_gb': 200,
@@ -315,6 +499,7 @@ class FakeHostManager(host_manager.HostManager):
                       'replication_type': 'dr',
                       'replication_domain': 'naboo',
                       'storage_protocol': 'NFS_CIFS',
+                      'vendor_name': 'Dummy',
                       },
             'host5': {'total_capacity_gb': 2048,
                       'free_capacity_gb': 500,
@@ -330,6 +515,7 @@ class FakeHostManager(host_manager.HostManager):
                       'create_share_from_snapshot_support': True,
                       'replication_type': None,
                       'storage_protocol': 'NFS_CIFS',
+                      'vendor_name': 'Dummy',
                       },
             'host6': {'total_capacity_gb': 'unknown',
                       'free_capacity_gb': 'unknown',
@@ -342,6 +528,20 @@ class FakeHostManager(host_manager.HostManager):
                       'create_share_from_snapshot_support': True,
                       'timestamp': None,
                       'storage_protocol': 'GLUSTERFS',
+                      'vendor_name': 'Dummy',
+                      },
+            'host7': {'total_capacity_gb': 'unknown',
+                      'free_capacity_gb': 'unknown',
+                      'allocated_capacity_gb': 1548,
+                      'thin_provisioning': False,
+                      'reserved_percentage': 5,
+                      'reserved_snapshot_percentage': 2,
+                      'reserved_share_extend_percentage': 5,
+                      'snapshot_support': True,
+                      'create_share_from_snapshot_support': True,
+                      'timestamp': None,
+                      'storage_protocol': 'NFS_CIFS',
+                      'vendor_name': 'Dummy',
                       },
         }
 
@@ -378,6 +578,9 @@ def mock_host_manager_db_calls(mock_obj, disabled=None):
         dict(id=6, host='host6', topic='share', disabled=False,
              availability_zone=FAKE_AZ_4, availability_zone_id=FAKE_AZ_4['id'],
              updated_at=timeutils.utcnow()),
+        dict(id=7, host='host7', topic='share', disabled=True,
+             availability_zone=FAKE_AZ_4, availability_zone_id=FAKE_AZ_4['id'],
+             updated_at=timeutils.utcnow()),
     ]
     if disabled is None:
         mock_obj.return_value = services
