@@ -89,6 +89,8 @@ dummy_opts = [
             "create_backup": "1.50",
             "restore_backup": "1.50",
 
+            "update_share_network_subnet_from_metadata": "0.5",
+
         },
     ),
 ]
@@ -147,6 +149,7 @@ class DummyDriver(driver.ShareDriver):
         self.migration_progress = {}
         self.security_service_update_support = True
         self.network_allocation_update_support = True
+        self.share_replicas_migration_support = True
 
     def _verify_configuration(self):
         allowed_driver_methods = [m for m in dir(self) if m[0] != '_']
@@ -181,6 +184,9 @@ class DummyDriver(driver.ShareDriver):
                 ))
 
     def _get_share_name(self, share):
+        mount_point_name = share.get('mount_point_name')
+        if mount_point_name is not None:
+            return mount_point_name
         return "share_%(s_id)s_%(si_id)s" % {
             "s_id": share["share_id"].replace("-", "_"),
             "si_id": share["id"].replace("-", "_")}
@@ -323,7 +329,7 @@ class DummyDriver(driver.ShareDriver):
 
     @slow_me_down
     def update_access(self, context, share, access_rules, add_rules,
-                      delete_rules, share_server=None):
+                      delete_rules, update_rules, share_server=None):
         """Update access rules for given share."""
         for rule in add_rules + access_rules:
             share_proto = share["share_proto"].lower()
@@ -516,6 +522,7 @@ class DummyDriver(driver.ShareDriver):
                 "consistent_snapshot_support": "pool",
             },
             'share_server_multiple_subnet_support': True,
+            'mount_point_name_support': True,
         }
         if self.configuration.replication_domain:
             data["replication_type"] = "readable"
@@ -1016,32 +1023,54 @@ class DummyDriver(driver.ShareDriver):
         }
 
     @slow_me_down
-    def create_backup(self, context, share_instance, backup):
+    def create_backup(self, context, share_instance, backup,
+                      share_server=None):
         LOG.debug("Created backup %(backup)s of share %(share)s "
                   "using dummy driver.",
                   {'backup': backup['id'],
                    'share': share_instance['share_id']})
 
-    def create_backup_continue(self, context, share_instance, backup):
+    def create_backup_continue(self, context, share_instance, backup,
+                               share_server=None):
         LOG.debug("Continue backup %(backup)s of share %(share)s "
                   "using dummy driver.",
                   {'backup': backup['id'],
                    'share': share_instance['share_id']})
         return {'total_progress': '100'}
 
-    def delete_backup(self, context, backup):
+    def delete_backup(self, context, backup, share_instance,
+                      share_server=None):
         LOG.debug("Deleted backup '%s' using dummy driver.", backup['id'])
 
     @slow_me_down
-    def restore_backup(self, context, backup, share_instance):
+    def restore_backup(self, context, backup, share_instance,
+                       share_server=None):
         LOG.debug("Restored backup %(backup)s into share %(share)s "
                   "using dummy driver.",
                   {'backup': backup['id'],
                    'share': share_instance['share_id']})
 
-    def restore_backup_continue(self, context, share_instance, backup):
+    def restore_backup_continue(self, context, backup, share_instance,
+                                share_server=None):
         LOG.debug("Continue restore of backup %(backup)s into share "
                   "%(share)s using dummy driver.",
                   {'backup': backup['id'],
                    'share': share_instance['share_id']})
         return {'total_progress': '100'}
+
+    def update_share_from_metadata(self, context, share_instance, metadata,
+                                   share_server=None):
+        LOG.debug("Updated share %(share)s. Metadata %(metadata)s "
+                  "applied successfully.",
+                  {'share': share_instance['share_id'],
+                   'metadata': metadata})
+
+    @slow_me_down
+    def update_share_network_subnet_from_metadata(self, context,
+                                                  share_network,
+                                                  share_network_subnet,
+                                                  share_servers, metadata):
+        LOG.debug("Updated share network subnet %(sn_sub)s. Metadata "
+                  "%(metadata)s applied successfully.",
+                  {'sn_sub': share_network_subnet['id'],
+                   'metadata': metadata})
