@@ -26,7 +26,6 @@ from manila.share.drivers.ganesha import manager
 from manila import test
 from manila import utils
 
-
 test_export_id = 101
 test_name = 'fakefile'
 test_path = '/fakedir0/export.d/fakefile.conf'
@@ -144,7 +143,7 @@ class GaneshaConfigTests(test.TestCase):
             # whitespace-split expressions to tokens with
             # (equality is forced to be treated as token by
             # sandwiching in space)
-            conf = map(lambda l: l.replace("=", " = ").split(), conf)
+            conf = map(lambda line: line.replace("=", " = ").split(), conf)
             # get rid of by-product empty lists (derived from superflouous
             # ";"-s that might have crept in due to "sandwiching")
             conf = map(lambda x: x, conf)
@@ -349,7 +348,7 @@ class GaneshaManagerTestCase(test.TestCase):
             self._manager._get_export_rados_object_name('fakeobj'))
 
     def test_write_tmp_conf_file(self):
-        self.mock_object(manager.pipes, 'quote',
+        self.mock_object(manager.shlex, 'quote',
                          mock.Mock(side_effect=['fakedata',
                                                 test_tmp_path]))
         test_args = [
@@ -371,7 +370,7 @@ class GaneshaManagerTestCase(test.TestCase):
         self._manager.execute.assert_has_calls([
             mock.call(*test_args[0]),
             mock.call(*test_args[1], **test_kwargs)])
-        manager.pipes.quote.assert_has_calls([
+        manager.shlex.quote.assert_has_calls([
             mock.call('fakedata'),
             mock.call(test_tmp_path)])
         self.assertEqual(test_tmp_path, ret)
@@ -972,8 +971,7 @@ class GaneshaManagerTestCase(test.TestCase):
         for method in methods:
             self.mock_object(self._manager, method)
 
-        self.assertRaises(exception.GaneshaCommandFailure,
-                          self._manager.remove_export, test_name)
+        ret = self._manager.remove_export(test_name)
 
         self._manager._read_export.assert_called_once_with(test_name)
         self.assertFalse(self._manager._remove_export_dbus.called)
@@ -994,6 +992,7 @@ class GaneshaManagerTestCase(test.TestCase):
             self.assertFalse(self._manager._delete_rados_object.called)
             self.assertFalse(
                 self._manager._remove_rados_object_url_from_index.called)
+        self.assertIsNone(ret)
 
     @ddt.data(True, False)
     def test_remove_export_error_during_remove_export_dbus_with_rados_store(
@@ -1012,8 +1011,7 @@ class GaneshaManagerTestCase(test.TestCase):
         for method in methods:
             self.mock_object(self._manager, method)
 
-        self.assertRaises(exception.GaneshaCommandFailure,
-                          self._manager.remove_export, test_name)
+        ret = self._manager.remove_export(test_name)
 
         self._manager._read_export.assert_called_once_with(test_name)
         self._manager._remove_export_dbus.assert_called_once_with(
@@ -1035,6 +1033,7 @@ class GaneshaManagerTestCase(test.TestCase):
             self.assertFalse(self._manager._delete_rados_object.called)
             self.assertFalse(
                 self._manager._remove_rados_object_url_from_index.called)
+        self.assertIsNone(ret)
 
     def test_get_rados_object(self):
         fakebin = chr(246).encode('utf-8')
