@@ -50,6 +50,7 @@ class NetAppCDOTDataMotionTestCase(test.TestCase):
         self.config.append_config_values(na_opts.netapp_cluster_opts)
         self.config.append_config_values(na_opts.netapp_connection_opts)
         self.config.append_config_values(na_opts.netapp_basicauth_opts)
+        self.config.append_config_values(na_opts.netapp_certificateauth_opts)
         self.config.append_config_values(na_opts.netapp_transport_opts)
         self.config.append_config_values(na_opts.netapp_support_opts)
         self.config.append_config_values(na_opts.netapp_provisioning_opts)
@@ -68,6 +69,14 @@ class NetAppCDOTDataMotionTestCase(test.TestCase):
                           group=self.backend)
         CONF.set_override("netapp_ssl_cert_path", "/etc/ssl/certs",
                           group=self.backend)
+        CONF.set_override("netapp_private_key_file", "fake_private_key.pem",
+                          group=self.backend)
+        CONF.set_override("netapp_certificate_file", "fake_cert.pem",
+                          group=self.backend)
+        CONF.set_override("netapp_ca_certificate_file", "fake_ca_cert.crt",
+                          group=self.backend)
+        CONF.set_override("netapp_certificate_host_validation", False,
+                          group=self.backend)
 
     def test_get_client_for_backend(self):
         self.mock_object(data_motion, "get_backend_configuration",
@@ -78,7 +87,11 @@ class NetAppCDOTDataMotionTestCase(test.TestCase):
         self.mock_cmode_client.assert_called_once_with(
             hostname='fake.hostname', password='fake_password',
             username='fake_user', transport_type='https', port=8866,
-            ssl_cert_path='/etc/ssl/certs', trace=mock.ANY, vserver=None)
+            ssl_cert_path='/etc/ssl/certs', trace=mock.ANY, vserver=None,
+            private_key_file='fake_private_key.pem',
+            certificate_file='fake_cert.pem',
+            ca_certificate_file='fake_ca_cert.crt',
+            certificate_host_validation=False)
 
     def test_get_client_for_backend_with_vserver(self):
         self.mock_object(data_motion, "get_backend_configuration",
@@ -93,7 +106,11 @@ class NetAppCDOTDataMotionTestCase(test.TestCase):
             hostname='fake.hostname', password='fake_password',
             username='fake_user', transport_type='https', port=8866,
             ssl_cert_path='/etc/ssl/certs', trace=mock.ANY,
-            vserver='fake_vserver')
+            vserver='fake_vserver',
+            private_key_file='fake_private_key.pem',
+            certificate_file='fake_cert.pem',
+            ca_certificate_file='fake_ca_cert.crt',
+            certificate_host_validation=False)
 
     def test_get_client_for_host(self):
         mock_extract_host = self.mock_object(
@@ -157,6 +174,7 @@ class NetAppCDOTDataMotionSessionTestCase(test.TestCase):
         config.append_config_values(na_opts.netapp_cluster_opts)
         config.append_config_values(na_opts.netapp_connection_opts)
         config.append_config_values(na_opts.netapp_basicauth_opts)
+        config.append_config_values(na_opts.netapp_certificateauth_opts)
         config.append_config_values(na_opts.netapp_transport_opts)
         config.append_config_values(na_opts.netapp_support_opts)
         config.append_config_values(na_opts.netapp_provisioning_opts)
@@ -507,7 +525,8 @@ class NetAppCDOTDataMotionSessionTestCase(test.TestCase):
             self.dest_vserver, self.fake_dest_vol_name)
 
         self.dm_session.quiesce_then_abort.assert_called_once_with(
-            self.fake_src_share, self.fake_dest_share)
+            self.fake_src_share, self.fake_dest_share,
+            quiesce_wait_time=None)
 
         self.mock_dest_client.mount_volume.assert_called_once_with(
             self.fake_dest_vol_name)
@@ -524,7 +543,8 @@ class NetAppCDOTDataMotionSessionTestCase(test.TestCase):
             self.dest_vserver, self.fake_dest_vol_name)
 
         self.dm_session.quiesce_then_abort.assert_called_once_with(
-            self.fake_src_share, self.fake_dest_share)
+            self.fake_src_share, self.fake_dest_share,
+            quiesce_wait_time=None)
 
         self.assertFalse(self.mock_dest_client.mount_volume.called)
 
@@ -535,7 +555,8 @@ class NetAppCDOTDataMotionSessionTestCase(test.TestCase):
                                          self.fake_dest_share)
 
         self.dm_session.quiesce_then_abort.assert_called_once_with(
-            self.fake_src_share, self.fake_dest_share)
+            self.fake_src_share, self.fake_dest_share,
+            quiesce_wait_time=None)
 
         self.mock_dest_client.break_snapmirror_vol.assert_called_once_with(
             self.source_vserver, self.fake_src_vol_name,
@@ -544,6 +565,39 @@ class NetAppCDOTDataMotionSessionTestCase(test.TestCase):
         self.mock_dest_client.mount_volume.assert_called_once_with(
             self.fake_dest_vol_name)
 
+    @ddt.data(None, 2, 30)
+    def test_quiesce_then_abort_wait_time(self, wait_time):
+        self.mock_object(time, 'sleep')
+        mock_get_snapmirrors = mock.Mock(
+            return_value=[{'relationship-status': "transferring"}])
+        self.mock_object(self.mock_dest_client, 'get_snapmirrors',
+                         mock_get_snapmirrors)
+        mock_backend_config = na_fakes.create_configuration()
+        mock_backend_config.netapp_snapmirror_quiesce_timeout = 10
+        self.mock_object(data_motion, 'get_backend_configuration',
+                         mock.Mock(return_value=mock_backend_config))
+
+        self.dm_session.quiesce_then_abort(self.fake_src_share,
+                                           self.fake_dest_share,
+                                           quiesce_wait_time=wait_time)
+
+        self.mock_dest_client.get_snapmirrors.assert_called_with(
+            source_vserver=self.source_vserver,
+            dest_vserver=self.dest_vserver,
+            source_volume=self.fake_src_vol_name,
+            dest_volume=self.fake_dest_vol_name,
+            desired_attributes=['relationship-status', 'mirror-state']
+        )
+
+        call_count = self.mock_dest_client.get_snapmirrors.call_count
+        if wait_time:
+            if wait_time > 5:
+                self.assertEqual(wait_time / 5, call_count)
+            else:
+                self.assertEqual(1, call_count)
+        else:
+            self.assertEqual(2, call_count)
+
     def test_quiesce_then_abort_timeout(self):
         self.mock_object(time, 'sleep')
         mock_get_snapmirrors = mock.Mock(
@@ -763,6 +817,7 @@ class NetAppCDOTDataMotionSessionTestCase(test.TestCase):
             dest_volume=self.fake_dest_vol_name,
             desired_attributes=['relationship-status',
                                 'mirror-state',
+                                'schedule',
                                 'source-vserver',
                                 'source-volume',
                                 'last-transfer-end-timestamp',
@@ -1235,3 +1290,43 @@ class NetAppCDOTDataMotionSessionTestCase(test.TestCase):
 
         mock_src_client.release_snapmirror_vol.assert_called()
         self.assertIsNone(result)
+
+    def test_get_most_available_aggr_of_vserver(self):
+        vserver_client = mock.Mock()
+        aggr_space_attr = {fake.AGGREGATE: {'available': 5678},
+                           'aggr2': {'available': 2024}}
+        self.mock_object(vserver_client,
+                         'get_vserver_aggregate_capacities',
+                         mock.Mock(return_value=aggr_space_attr))
+        result = self.dm_session.get_most_available_aggr_of_vserver(
+            vserver_client)
+        self.assertEqual(result, fake.AGGREGATE)
+
+    def test_initialize_and_wait_snapmirror_vol(self):
+        vserver_client = mock.Mock()
+        snapmirror_info = [{'source-vserver': fake.VSERVER1,
+                            'source-volume': "fake_source_vol",
+                            'destination-vserver': fake.VSERVER2,
+                            'destination-volume': "fake_des_vol",
+                            'relationship-status': "idle"}]
+        self.mock_object(vserver_client,
+                         'get_snapmirrors',
+                         mock.Mock(return_value=snapmirror_info))
+
+        (self.dm_session.
+         initialize_and_wait_snapmirror_vol(vserver_client,
+                                            fake.VSERVER1,
+                                            fake.FLEXVOL_NAME,
+                                            fake.VSERVER2,
+                                            fake.FLEXVOL_NAME_1,
+                                            source_snapshot=None,
+                                            transfer_priority=None,
+                                            timeout=300))
+        (vserver_client.initialize_snapmirror_vol.
+         assert_called_once_with(mock.ANY,
+                                 mock.ANY,
+                                 mock.ANY,
+                                 mock.ANY,
+                                 source_snapshot=mock.ANY,
+                                 transfer_priority=mock.ANY,
+                                 ))
