@@ -72,6 +72,7 @@ ROOT_AGGREGATES = ('root_aggr_1', 'root_aggr_2')
 ROOT_VOLUME_AGGREGATE = 'manila1'
 SECURITY_CERT_DEFAULT_EXPIRE_DAYS = 365
 SECURITY_CERT_LARGE_EXPIRE_DAYS = 3652
+DELETE_RETENTION_HOURS = 12
 ROOT_VOLUME = 'root'
 CLUSTER_NODE = 'cluster1_01'
 CLUSTER_NODES = ('cluster1_01', 'cluster1_02')
@@ -128,6 +129,10 @@ CLIENT_KWARGS = {
     'transport_type': 'https',
     'ssl_cert_path': '/etc/ssl/certs/',
     'password': 'pass',
+    'private_key_file': 'fake_private_key.pem',
+    'certificate_file': 'fake_certificate.pem',
+    'ca_certificate_file': 'fake_ca_certificate.crt',
+    'certificate_host_validation': False,
     'port': '443',
     'api_trace_pattern': '(.*)',
 }
@@ -1081,6 +1086,7 @@ POOLS = [
         'netapp_flexgroup': False,
         'netapp_cluster_name': 'fake_cluster_name',
         'netapp_snaplock_type': 'compliance',
+        'share_replicas_migration_support': True,
     },
     {
         'pool_name': AGGREGATES[1],
@@ -1111,6 +1117,7 @@ POOLS = [
         'netapp_flexgroup': False,
         'netapp_cluster_name': 'fake_cluster_name',
         'netapp_snaplock_type': 'compliance',
+        'share_replicas_migration_support': True
     },
 ]
 
@@ -1141,6 +1148,7 @@ POOLS_VSERVER_CREDS = [
         'security_service_update_support': True,
         'share_server_multiple_subnet_support': True,
         'netapp_flexgroup': False,
+        'share_replicas_migration_support': True
     },
     {
         'pool_name': AGGREGATES[1],
@@ -1164,6 +1172,7 @@ POOLS_VSERVER_CREDS = [
         'security_service_update_support': True,
         'share_server_multiple_subnet_support': True,
         'netapp_flexgroup': False,
+        'share_replicas_migration_support': True
     },
 ]
 
@@ -1954,6 +1963,11 @@ def get_config_cmode():
     config.netapp_transport_type = CLIENT_KWARGS['transport_type']
     config.netapp_ssl_cert_path = CLIENT_KWARGS['ssl_cert_path']
     config.netapp_server_port = CLIENT_KWARGS['port']
+    config.netapp_private_key_file = CLIENT_KWARGS['private_key_file']
+    config.netapp_certificate_file = CLIENT_KWARGS['certificate_file']
+    config.netapp_ca_certificate_file = CLIENT_KWARGS['ca_certificate_file']
+    config.netapp_certificate_host_validation = \
+        CLIENT_KWARGS['certificate_host_validation']
     config.netapp_volume_name_template = VOLUME_NAME_TEMPLATE
     config.netapp_aggregate_name_search_pattern = AGGREGATE_NAME_SEARCH_PATTERN
     config.netapp_vserver_name_template = VSERVER_NAME_TEMPLATE
