@@ -48,6 +48,18 @@ class ShareRpcAPITestCase(test.TestCase):
         share_group_snapshot = {'id': 'fake_share_group_id'}
         host = 'fake_host'
         share_server = db_utils.create_share_server(host=host)
+        share_network_subnet = {
+            'id': 'fake share network subnet',
+            'availability_zone_id': 'fake_az_id',
+            'neutron_net_id': 'fake_neutron_net_id',
+            'neutron_subnet_id': 'fake_neutron_subnet_id',
+            'ip_version': 4,
+            'cidr': '127.0.0.0/28',
+            'gateway': '127.0.0.1',
+            'mtu': 1500,
+            'network_type': 'vlan',
+            'segmentation_id': 3000,
+        }
         self.fake_share = jsonutils.to_primitive(share)
         # mock out the getattr on the share db model object since jsonutils
         # doesn't know about those extra attributes to pull in
@@ -61,6 +73,8 @@ class ShareRpcAPITestCase(test.TestCase):
         self.fake_share_group_snapshot = jsonutils.to_primitive(
             share_group_snapshot)
         self.fake_host = jsonutils.to_primitive(host)
+        self.fake_share_network_subnet = jsonutils.to_primitive(
+            share_network_subnet)
         self.ctxt = context.RequestContext('fake_user', 'fake_project')
         self.rpcapi = share_rpcapi.ShareAPI()
 
@@ -117,7 +131,8 @@ class ShareRpcAPITestCase(test.TestCase):
             expected_msg['snapshot_instance_id'] = snapshot_instance['id']
         share_server_id_methods = [
             'manage_share_server', 'unmanage_share_server',
-            'share_server_migration_start', 'share_server_migration_check']
+            'share_server_migration_start', 'share_server_migration_check',
+            'update_share_network_subnet_from_metadata']
         src_dest_share_server_methods = [
             'share_server_migration_cancel',
             'share_server_migration_get_progress',
@@ -134,6 +149,8 @@ class ShareRpcAPITestCase(test.TestCase):
                 and method in src_dest_share_server_methods):
             share_server = expected_msg.pop('dest_share_server', None)
             expected_msg['dest_share_server_id'] = share_server['id']
+        if method == 'ensure_driver_resources':
+            expected_msg['skip_backend_info_check'] = True
 
         if 'host' in kwargs:
             host = kwargs['host']
@@ -194,9 +211,10 @@ class ShareRpcAPITestCase(test.TestCase):
     def test_delete_share_instance(self):
         self._test_share_api('delete_share_instance',
                              rpc_method='cast',
-                             version='1.4',
+                             version='1.27',
                              share_instance=self.fake_share,
-                             force=False)
+                             force=False,
+                             deferred_delete=False)
 
     def test_update_access(self):
         self._test_share_api('update_access',
@@ -213,15 +231,26 @@ class ShareRpcAPITestCase(test.TestCase):
     def test_delete_snapshot(self):
         self._test_share_api('delete_snapshot',
                              rpc_method='cast',
+                             version='1.27',
                              snapshot=self.fake_snapshot,
                              host='fake_host',
-                             force=False)
+                             force=False,
+                             deferred_delete=False)
 
     def test_delete_share_server(self):
         self._test_share_api('delete_share_server',
                              rpc_method='cast',
                              share_server=self.fake_share_server)
 
+    def test_transfer_accept(self):
+        self._test_share_api('transfer_accept',
+                             rpc_method='call',
+                             version='1.25',
+                             share=self.fake_share,
+                             new_user='new_user',
+                             new_project='new_project',
+                             clear_rules=False)
+
     def test_extend_share(self):
         self._test_share_api('extend_share',
                              rpc_method='cast',
@@ -317,8 +346,9 @@ class ShareRpcAPITestCase(test.TestCase):
     def test_promote_share_replica(self):
         self._test_share_api('promote_share_replica',
                              rpc_method='cast',
-                             version='1.8',
-                             share_replica=self.fake_share_replica)
+                             version='1.24',
+                             share_replica=self.fake_share_replica,
+                             quiesce_wait_time=None)
 
     def test_update_share_replica(self):
         self._test_share_api('update_share_replica',
@@ -365,6 +395,23 @@ class ShareRpcAPITestCase(test.TestCase):
                              host='fake_host',
                              reservations={'fake': 'fake'})
 
+    def test_update_share_from_metadata(self):
+        self._test_share_api('update_share_from_metadata',
+                             rpc_method='cast',
+                             version='1.28',
+                             share=self.fake_share,
+                             metadata={'fake': 'fake'})
+
+    def test_update_share_network_subnet_from_metadata(self):
+        self._test_share_api(
+            'update_share_network_subnet_from_metadata',
+            rpc_method='cast',
+            version='1.30',
+            share_network_id='fake_net_id',
+            share_network_subnet_id=self.fake_share_network_subnet['id'],
+            share_server=self.fake_share_server,
+            metadata={'fake': 'fake'})
+
     def test_create_replicated_snapshot(self):
         self._test_share_api('create_replicated_snapshot',
                              rpc_method='cast',
@@ -457,3 +504,48 @@ class ShareRpcAPITestCase(test.TestCase):
             dest_host=self.fake_host,
             share_instance_ids=[self.fake_share['instance']['id']],
             share_server_id=self.fake_share_server['id'])
+
+    def test_update_share_network_security_service(self):
+        self._test_share_api(
+            'update_share_network_security_service',
+            rpc_method='cast',
+            version='1.22',
+            dest_host=self.fake_host,
+            share_network_id='fake_net_id',
+            new_security_service_id='fake_sec_service_id',
+            current_security_service_id='fake_sec_service_id')
+
+    def test_check_update_share_network_security_service(self):
+        self._test_share_api('check_update_share_network_security_service',
+                             rpc_method='cast',
+                             version='1.22',
+                             dest_host=self.fake_host,
+                             share_network_id='fake_net_id',
+                             new_security_service_id='fake_sec_service_id',
+                             current_security_service_id='fake_sec_service_id')
+
+    def test_check_update_share_server_network_allocations(self):
+        self._test_share_api(
+            'check_update_share_server_network_allocations',
+            rpc_method='cast',
+            version='1.23',
+            dest_host=self.fake_host,
+            share_network_id='fake_net_id',
+            new_share_network_subnet=self.fake_share_network_subnet)
+
+    def test_update_share_server_network_allocations(self):
+        self._test_share_api(
+            'update_share_server_network_allocations',
+            rpc_method='cast',
+            version='1.23',
+            dest_host=self.fake_host,
+            share_network_id='fake_net_id',
+            new_share_network_subnet_id='new_share_network_subnet_id')
+
+    def test_ensure_driver_resources(self):
+        self._test_share_api(
+            'ensure_driver_resources',
+            rpc_method='cast',
+            version='1.29',
+            host=self.fake_host,
+        )
